## Changelog

### 0.0.6
crt ID 4969192134 revealed an improper encoded DER certificate. Error trapping added 

### 0.0.6
crt ID 881434381 revealed an issue with error trapping when no CACertificate is found in the certificate

### 0.0.5
Initial Release
